kolla_cli Package
=================

:mod:`i18n` Module
------------------

.. automodule:: kolla_cli.i18n
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`shell` Module
-------------------

.. automodule:: kolla_cli.shell
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    kolla_cli.api
    kolla_cli.commands
    kolla_cli.common
    kolla_cli.tests

